==> glibc-1.06.4.tar.bz2: glibc-1.06.4/sysdeps/unix/bsd/sony/newsos/m68k/sysdep.h <==
/* Copyright (C) 1993 Free Software Foundation, Inc.
This file is part of the GNU C Library.

The GNU C Library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public License as
published by the Free Software Foundation; either version 2 of the
License, or (at your option) any later version.

The GNU C Library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with the GNU C Library; see the file COPYING.LIB.  If
not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.  */

/* This code wants to be run through m4.  */

#include <sysdeps/unix/sysdep.h>

#define	POUND(foo)	(@@@Hash-Here@@@)foo

#ifdef	__STDC__
#define	ENTRY(name)							      \
  .globl _##name;							      \
  .even;								      \
  _##name##:
#else
#define	ENTRY(name)							      \
  .globl _/**/name;							      \
  .even;								      \
  _/**/name/**/:
#endif

#define	PSEUDO(name, syscall_name, args)				      \
  .even;								      \
  .globl syscall_error;							      \
  error: jmp syscall_error;						      \
  ENTRY (name)								      \
  DO_CALL (syscall_name, args)

#ifdef __STDC__
#define DO_CALL(syscall_name, args)					      \
  linkw fp, POUND(0);							      \
  movel POUND(SYS_##syscall_name), d0;					      \
  trap POUND(0);							      \
  unlk fp;								      \
  bcs error
#else
#define DO_CALL(syscall_name, args)					      \
  linkw fp, POUND(0);							      \
  movel POUND(SYS_/**/syscall_name), d0;				      \
  trap POUND(0);							      \
  unlk fp;								      \
  bcs error
#endif

#define	ret	rts
#define	r0	d0
#define	r1	d1
#define	MOVE(x,y)	movel x , y

==> glibc-2.0.tar.bz2: glibc-2.0/sysdeps/unix/bsd/sony/newsos/m68k/sysdep.h <==
/* Copyright (C) 1993, 1994, 1995 Free Software Foundation, Inc.
This file is part of the GNU C Library.

The GNU C Library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public License as
published by the Free Software Foundation; either version 2 of the
License, or (at your option) any later version.

The GNU C Library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with the GNU C Library; see the file COPYING.LIB.  If
not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.  */

#include <sysdeps/unix/sysdep.h>

#ifdef ASSEMBLER

#define	POUND	#

#ifdef	__STDC__
#define	ENTRY(name)							      \
  .globl _##name;							      \
  .even;								      \
  _##name##:
#else
#define	ENTRY(name)							      \
  .globl _/**/name;							      \
  .even;								      \
  _/**/name/**/:
#endif

#define	PSEUDO(name, syscall_name, args)				      \
  .even;								      \
  .globl syscall_error;							      \
  error: jmp syscall_error;						      \
  ENTRY (name)								      \
  DO_CALL (POUND SYS_ify (syscall_name), args)

#define DO_CALL(syscall, args)						      \
  movel syscall, d0;							      \
  linkw a6, POUND(0);							      \
  trap POUND(0);							      \
  unlk a6;								      \
  bcs error

#define	ret	rts
#define	r0	d0
#define	r1	d1
#define	MOVE(x,y)	movel x , y

#endif
